package scichart.bug.scichartsandbox

import android.graphics.Color
import android.os.Bundle
import android.os.Handler
import android.os.Looper
import android.support.v7.app.AppCompatActivity
import android.widget.Button
import com.scichart.charting.model.dataSeries.XyDataSeries
import com.scichart.charting.visuals.SciChartSurface
import com.scichart.charting.visuals.annotations.VerticalLineAnnotation
import com.scichart.extensions.builders.SciChartBuilder
import java.util.*

class MainActivity : AppCompatActivity()
{
    private lateinit var chartBuilder: SciChartBuilder
    private lateinit var surface: SciChartSurface
    private lateinit var cursor: VerticalLineAnnotation
    private lateinit var button: Button

    private val random = Random()
    private val handler = Handler(Looper.getMainLooper())

    private val updateTask: Runnable by lazy {
        Runnable {
            updateChart()
            handler.postDelayed(updateTask, 1000)
        }
    }

    override fun onCreate(savedInstanceState: Bundle?)
    {
        super.onCreate(savedInstanceState)

//        SciChartSurface.setRuntimeLicenseKey(getString(R.string.sciChart_license))
        SciChartBuilder.init(this)
        chartBuilder = SciChartBuilder.instance()

        setContentView(R.layout.activity_main)
        surface = findViewById(R.id.surface)
        button = findViewById(R.id.button)

        initChart()

        button.setOnClickListener {
            if (surface.annotations.isEmpty()) surface.annotations.add(cursor)
            else                               surface.annotations.remove(cursor)
        }

        handler.post(updateTask)
    }

    private fun initChart()
    {
        val xAxis = chartBuilder.newNumericAxis().build()
        val yAxis = chartBuilder.newNumericAxis().build()

        val columnSeries = chartBuilder.newColumnSeries()
            .withDataPointWidth(0.7)
            .withDataSeries(chartBuilder.newXyDataSeries(Int::class.javaObjectType, Int::class.javaObjectType).build())
            .build()

        cursor = chartBuilder.newVerticalLineAnnotation()
            .withStroke(1f, Color.RED)
            .withXValue(2)
            .build()

        surface.xAxes.add(xAxis)
        surface.yAxes.add(yAxis)
        surface.renderableSeries.add(columnSeries)
    }

    private fun updateChart()
    {
        @Suppress("UNCHECKED_CAST")
        val dataSeries = surface.renderableSeries.first().dataSeries as XyDataSeries<Int, Int>
        dataSeries.clear()
        dataSeries.append(listOf(1, 2, 3, 4, 5), listOf(random.nextInt(20), random.nextInt(20), random.nextInt(20), random.nextInt(20), random.nextInt(20)))
    }
}